
# Type: slots


list of slot names that are applicable to a class

URI: [meta:slots](https://w3id.org/biolink/biolinkml/meta/slots)


## Domain and Range

[ClassDefinition](ClassDefinition.md) ->  <sub>0..*</sub> [SlotDefinition](SlotDefinition.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | This defines the set of slots that are allowed to be used for a given class. The final list of slots for a class is the combination of the parent (is a) slots, mixins slots, apply to slots minus the slot usage entries. Formally,  |

